@@ -11,6 +11,7 @@ from ctlml_commons.entity.focus.focus_plugins import FocusPlugins
 from ctlml_commons.entity.lot import Lot
 from ctlml_commons.entity.news import News
 from ctlml_commons.entity.range_window import RangeWindow
+from ctlml_commons.util.num_utils import convert_floats
 
 
 @dataclass(frozen=True)
@@ -35,14 +36,21 @@ class PercentageFocus(Focus):
         logger: Optional[Logger] = None,
     ) -> Tuple[bool, str]:
         return FocusPlugins.should_buy_percentage_wise(
-            symbol=symbol, current_price=current_price, candles=candles, percentage_up=self.percentage_up
+            symbol=symbol,
+            current_price=current_price,
+            candles=candles,
+            percentage_up=self.percentage_up,
+            logger=logger,
         )
 
     def evaluate_sell(
         self, lot: Lot, news: List[News], current_price: float, candles: Dict[str, Candle], logger: Logger
     ) -> Tuple[bool, str]:
         return FocusPlugins.should_sell_percentage_wise(
-            lot=lot, current_price=current_price, percentage_window=self.percentage_window
+            lot=lot,
+            current_price=current_price,
+            percentage_window=self.percentage_window,
+            logger=logger,
         )
 
     def serialize(self) -> Dict[str, Any]:
@@ -57,5 +65,6 @@ class PercentageFocus(Focus):
 
         del data["focus_type"]
         data["percentage_window"] = RangeWindow.deserialize(data["percentage_window"])
+        data = convert_floats(input_data=data, keys=["percentage_up"])
 
         return cls(**data)
