@@ -11,6 +11,7 @@ from ctlml_commons.entity.focus.focus_plugins import FocusPlugins
 from ctlml_commons.entity.lot import Lot
 from ctlml_commons.entity.news import News
 from ctlml_commons.entity.range_window import RangeWindow
+from ctlml_commons.util.num_utils import convert_floats
 
 
 @dataclass(frozen=True)
@@ -33,7 +34,10 @@ class PriceFocus(Focus):
         self, symbol: str, news: List[News], current_price: float, candles: Dict[str, Candle], logger: Logger
     ) -> Tuple[bool, str]:
         return FocusPlugins.should_buy_price_wise(
-            current_price=current_price, candles=candles, num_periods=self.num_periods
+            current_price=current_price,
+            candles=candles,
+            num_periods=self.num_periods,
+            logger=logger,
         )
 
     def evaluate_sell(
@@ -44,6 +48,7 @@ class PriceFocus(Focus):
             current_price=current_price,
             total_threshold=self.total_threshold,
             per_share_price_window=self.per_share_price_window,
+            logger=logger,
         )
 
     def serialize(self) -> Dict[str, Any]:
@@ -59,4 +64,7 @@ class PriceFocus(Focus):
         del data["focus_type"]
         data["per_share_price_window"] = RangeWindow.deserialize(data["per_share_price_window"])
 
+        data = convert_floats(input_data=data, keys=["total_threshold"])
+        data["num_periods"] = int(data["num_periods"])
+
         return cls(**data)
