@@ -15,18 +15,19 @@ class Lot:
     """Uniquely identifies an ingress execution, i.e. BUY 10 of ABCD at LIMIT price of 0.1."""
 
     id: UUID  # Internal id
+    investor: str # Investor name
     symbol: str  # Ticker
     shares: float  # Shares
     purchase_price: float  # Price per share
     notes: str  # Summary of why this lot was created
-    investment_strategy_data: str
+    strategy: str
     purchase_time: datetime  # Purchase time
-    b_id: Optional[UUID] = None  # Brokerage external id
+    brokerage_id: Optional[UUID] = None  # Brokerage external id
 
     def serialize(self) -> Dict[str, Any]:
         data: Dict[str, Any] = deepcopy(self.__dict__)
 
-        for field in ["id", "b_id"]:
+        for field in ["id", "brokerage_id"]:
             data[field] = str(data[field])
 
         data["purchase_time"] = datetime_to_str(self.purchase_time)
@@ -36,13 +37,14 @@ class Lot:
     def add_brokerage_id(self, b_id: UUID) -> Lot:
         return Lot(
             id=self.id,
+            investor=self.investor,
             symbol=self.symbol,
             shares=self.shares,
             purchase_price=self.purchase_price,
             notes=self.notes,
             purchase_time=self.purchase_time,
-            investment_strategy_data=self.investment_strategy_data,
-            b_id=b_id,
+            strategy=self.strategy,
+            brokerage_id=b_id,
         )
 
     @classmethod
@@ -53,10 +55,10 @@ class Lot:
     def clean(cls, input_data: Dict[str, Any]) -> Dict[str, Any]:
         data = deepcopy(input_data)
 
-        for field in ["id", "b_id"]:
+        for field in ["id", "brokerage_id"]:
             data[field] = UUID(data[field])
 
-        data = convert_floats(data, ["shares"])
+        data = convert_floats(data, ["purchase_price", "shares"])
         data = convert_dates(data, "purchase_time")
 
-        return data
+        return data
\ No newline at end of file
