@@ -34,7 +34,7 @@ class Portfolio:
     withdrawable_amount: float
     unwithdrawable_deposits: float
     unwithdrawable_grants: float
-    other: field(default_factory=dict)
+    other: Dict[str, str] = field(default_factory=dict)
 
     def serialize(self) -> Dict[str, Any]:
         data = deepcopy(self.__dict__)
