@@ -124,36 +124,48 @@ def readable_date_to_str(a_date: datetime = to_est(), format_str: str = "%Y-%m-%
     return a_date.strftime(format_str)
 
 
-def time_offset(seconds: int, a_datetime=to_est()) -> datetime:
-    """Offset in seconds from a time.
+def time_forward(seconds: int, a_datetime=to_est()) -> datetime:
+    """Forward offset in seconds from a time.
+
+    Args:
+        seconds: seconds to add
+        a_datetime: time
+
+    Returns: forward time
+    """
+    return a_datetime + timedelta(seconds=seconds)
+
+
+def time_backward(seconds: int, a_datetime=to_est()) -> datetime:
+    """Backward offset in seconds from a time.
 
     Args:
         seconds: seconds to offset
         a_datetime: time
 
-    Returns: offset time
+    Returns: backward time
     """
     return a_datetime - timedelta(seconds=seconds)
 
 
-def time_offset_in_days(days: int, a_datetime=to_est()) -> datetime:
-    """Offset in days from a time.
+def time_backward_in_days(days: int, a_datetime=to_est()) -> datetime:
+    """Backward offset in days from a time.
 
     Args:
         days: days to offset
         a_datetime: time
 
-    Returns: offset time
+    Returns: backward time
     """
     return a_datetime - timedelta(days=days)
 
 
-def timeoffset_as_str(seconds: int, a_datetime=to_est()) -> str:
-    """Provides a minute representation.
+def time_backward_as_str(seconds: int, a_datetime=to_est()) -> str:
+    """Backward offset in seconds from a time. Then converted to a string.
 
-    Returns: a year, month, day, hour, minute string
+    Returns: backward time as string
     """
-    return time_to_str(time_offset(seconds=seconds, a_datetime=a_datetime))
+    return time_to_str(time_backward(seconds=seconds, a_datetime=a_datetime))
 
 
 def timestamp_strs_for_window(
@@ -171,7 +183,7 @@ def timestamp_strs_for_window(
 
     Returns: list of times descending from a start time to the past.
     """
-    return [timeoffset_as_str(seconds=r * seconds, a_datetime=a_datetime) for r in range(window)]
+    return [timebackward_as_str(seconds=r * seconds, a_datetime=a_datetime) for r in range(window)]
 
 
 def floor_sec_timestamp(a_time: datetime = to_est(), second_granularity: int = 10) -> datetime:
@@ -208,9 +220,7 @@ def is_holiday(a_time: datetime = to_est(), format_str: str = "%Y-%m-%d", logger
 
 def is_weekend(a_time: datetime = to_est(), logger: Optional[Logger] = None) -> bool:
     if logger:
-        logger.info(
-            f"is_weekend: {a_time} - {True if a_time.date().weekday() > 4 else False}"
-        )
+        logger.info(f"is_weekend: {a_time} - {True if a_time.date().weekday() > 4 else False}")
     return True if a_time.date().weekday() > 4 else False
 
 
